@@ -5,7 +5,7 @@ from s2python.generated.gen_s2 import (
 )
 
 from s2python.validate_values_mixin import (
-    S2Message,
+    S2MessageComponent,
     catch_and_convert_exceptions,
 )
 
@@ -15,12 +15,10 @@ from s2python.ppbc.ppbc_power_sequence_container_status import (
 
 
 @catch_and_convert_exceptions
-class PPBCPowerProfileStatus(
-    GenPPBCPowerProfileStatus, S2Message["PPBCPowerProfileStatus"]
-):
+class PPBCPowerProfileStatus(GenPPBCPowerProfileStatus, S2MessageComponent):
     model_config = GenPPBCPowerProfileStatus.model_config
     model_config["validate_assignment"] = True
 
-    sequence_container_status: List[PPBCPowerSequenceContainerStatus] = (
+    sequence_container_status: List[PPBCPowerSequenceContainerStatus] = (  # type: ignore[reportIncompatibleVariableOverride]
         GenPPBCPowerProfileStatus.model_fields["sequence_container_status"]  # type: ignore[assignment]
     )
